@@ -1,11 +1,8 @@
-"""
-Fixtures factories.
-"""
+"""Fixtures factories."""
+
 import factory
 
-from modoboa.admin.factories import (
-    DomainFactory, MailboxFactory
-)
+from modoboa.admin import factories as admin_factories
 
 from . import models
 
@@ -16,7 +13,7 @@ class UserCalendarFactory(factory.DjangoModelFactory):
         model = models.UserCalendar
 
     name = factory.Sequence(lambda n: 'User calendar %s' % n)
-    mailbox = factory.SubFactory(MailboxFactory)
+    mailbox = factory.SubFactory(admin_factories.MailboxFactory)
 
 
 class SharedCalendarFactory(factory.DjangoModelFactory):
@@ -25,7 +22,7 @@ class SharedCalendarFactory(factory.DjangoModelFactory):
         model = models.SharedCalendar
 
     name = factory.Sequence(lambda n: 'Shared calendar %s' % n)
-    domain = factory.SubFactory(DomainFactory)
+    domain = factory.SubFactory(admin_factories.DomainFactory)
 
 
 class AccessRuleFactory(factory.DjangoModelFactory):
@@ -33,5 +30,5 @@ class AccessRuleFactory(factory.DjangoModelFactory):
     class Meta:
         model = models.AccessRule
 
-    mailbox = factory.SubFactory(MailboxFactory)
+    mailbox = factory.SubFactory(admin_factories.MailboxFactory)
     calendar = factory.SubFactory(UserCalendarFactory)
